summaryrefslogtreecommitdiff
path: root/apt
diff options
context:
space:
mode:
Diffstat (limited to 'apt')
-rw-r--r--apt/package.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/apt/package.py b/apt/package.py
index 14e80594..9223ed22 100644
--- a/apt/package.py
+++ b/apt/package.py
@@ -343,7 +343,7 @@ class Version(object):
def description(self):
"""Return the formatted long description.
Return the formated long description according to the Debian policy
(Chapter 5.6.13).
See http://www.debian.org/doc/debian-policy/ch-controlfields.html
for more information.
@@ -892,7 +892,7 @@ class Package(object):
def description(self):
"""Return the formatted long description.
Return the formated long description according to the Debian policy
(Chapter 5.6.13).
See http://www.debian.org/doc/debian-policy/ch-controlfields.html
for more information.
@@ -1142,7 +1142,7 @@ class Package(object):
return u""
# Read changelog line by line
line_raw = changelog_file.readline()
- if line_raw == "":
+ if not line_raw:
break
# The changelog is encoded in utf-8, but since there isn't
# any http header, urllib2 seems to treat it as ascii
@@ -1360,8 +1360,8 @@ def _test():
print "SourcePkg: %s " % pkg.candidate.source_name
print "Section: %s " % pkg.section
print "Summary: %s" % pkg.candidate.summary
- print "Description (formated) :\n%s" % pkg.candidate.description
- print "Description (unformated):\n%s" % pkg.candidate.raw_description
+ print "Description (formatted) :\n%s" % pkg.candidate.description
+ print "Description (unformatted):\n%s" % pkg.candidate.raw_description
print "InstalledSize: %s " % pkg.candidate.installed_size
print "PackageSize: %s " % pkg.candidate.size
print "Dependencies: %s" % pkg.installed.dependencies
@@ -343,7 +343,7 @@ class Version(object):
def description(self):
"""Return the formatted long description.
- Return the formated long description according to the Debian policy
+ Return the formatted long description according to the Debian policy
(Chapter 5.6.13).
See http://www.debian.org/doc/debian-policy/ch-controlfields.html
@@ -892,7 +892,7 @@ class Package(object):
def description(self):
"""Return the formatted long description.
- Return the formated long description according to the Debian policy
+ Return the formatted long description according to the Debian policy
(Chapter 5.6.13).
See http://www.debian.org/doc/debian-policy/ch-controlfields.html